@@ -270,16 +270,17 @@ func TestRunPipe(t *testing.T) {
 			assertImageLabels:   noLabels,
 			extraPrepare: func(t *testing.T, ctx *context.Context) {
 				t.Helper()
-				_ = exec.Command(fmt.Sprintf("docker manifest rm %sgoreleaser/test_multiarch:2test ", registry)).Run()
 				for _, cmd := range []string{
+					fmt.Sprintf("docker manifest rm %sgoreleaser/test_multiarch:2test || true", registry),
 					fmt.Sprintf("docker build -t %sgoreleaser/dummy:v1 --platform linux/amd64 -f testdata/Dockerfile.dummy .", registry),
 					fmt.Sprintf("docker push %sgoreleaser/dummy:v1", registry),
 					fmt.Sprintf("docker manifest create %sgoreleaser/test_multiarch:2test --amend %sgoreleaser/dummy:v1 --insecure", registry, registry),
 				} {
-					// t.Log("running", cmd)
-					parts := strings.Fields(cmd)
+					parts := strings.Fields(strings.TrimSuffix(cmd, " || true"))
 					out, err := exec.CommandContext(ctx, parts[0], parts[1:]...).CombinedOutput()
-					require.NoError(t, err, cmd+": "+string(out))
+					if !strings.HasSuffix(cmd, " || true") {
+						require.NoError(t, err, cmd+": "+string(out))
+					}
 				}
 			},
 		},
@@ -1091,6 +1092,13 @@ func TestRunPipe(t *testing.T) {
 					// t.Log("removing docker image", img)
 					require.NoError(t, rmi(img), "could not delete image %s", img)
 				}
+
+				_ = ctx.Artifacts.Filter(artifact.ByType(artifact.DockerImage)).Visit(func(a *artifact.Artifact) error {
+					digest, err := artifact.Extra[string](*a, artifact.ExtraDigest)
+					require.NoError(t, err)
+					require.NotEmpty(t, digest)
+					return nil
+				})
 			})
 		}
 	}
@@ -1174,6 +1182,7 @@ func TestDefault(t *testing.T) {
 	docker := ctx.Config.Dockers[0]
 	require.Equal(t, "linux", docker.Goos)
 	require.Equal(t, "amd64", docker.Goarch)
+	require.Equal(t, "6", docker.Goarm)
 	require.Equal(t, []string{"aa"}, docker.IDs)
 	require.Equal(t, useDocker, docker.Use)
 	docker = ctx.Config.Dockers[1]
@@ -1414,3 +1423,42 @@ func TestSkip(t *testing.T) {
 		})
 	})
 }
+
+func TestWithDigest(t *testing.T) {
+	artifacts := artifact.New()
+	artifacts.Add(&artifact.Artifact{
+		Name: "localhost:5050/owner/img:t1",
+		Type: artifact.DockerImage,
+		Extra: artifact.Extras{
+			artifact.ExtraDigest: "sha256:d1",
+		},
+	})
+	artifacts.Add(&artifact.Artifact{
+		Name: "localhost:5050/owner/img:t2",
+		Type: artifact.DockerImage,
+		Extra: artifact.Extras{
+			artifact.ExtraDigest: "sha256:d2",
+		},
+	})
+	artifacts.Add(&artifact.Artifact{
+		Name: "localhost:5050/owner/img:t3",
+		Type: artifact.DockerImage,
+	})
+
+	for _, use := range []string{useDocker, useBuildx} {
+		use := use
+		t.Run(use, func(t *testing.T) {
+			t.Run("good", func(t *testing.T) {
+				require.Equal(t, "localhost:5050/owner/img:t1@sha256:d1", withDigest(use, "localhost:5050/owner/img:t1", artifacts.List()))
+			})
+
+			t.Run("no digest", func(t *testing.T) {
+				require.Equal(t, "localhost:5050/owner/img:t3", withDigest(use, "localhost:5050/owner/img:t3", artifacts.List()))
+			})
+
+			t.Run("no match", func(t *testing.T) {
+				require.Equal(t, "localhost:5050/owner/img:t4", withDigest(use, "localhost:5050/owner/img:t4", artifacts.List()))
+			})
+		})
+	}
+}
