@@ -5,7 +5,6 @@ import (
 	"io"
 	"net/http"
 	"net/http/httptest"
-	"os"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -92,8 +91,7 @@ func TestPostWebhook(t *testing.T) {
 	ctx.ReleaseURL = "https://github.com/honk/honk/releases/tag/v1.0.0"
 	ctx.Git.URL = "https://github.com/honk/honk"
 
-	os.Setenv("MATTERMOST_WEBHOOK", ts.URL)
-	defer os.Unsetenv("MATTERMOST_WEBHOOK")
+	t.Setenv("MATTERMOST_WEBHOOK", ts.URL)
 
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, Pipe{}.Announce(ctx))
